==> jc-1.4.0.tar.gz: java/awt/GraphicsConfigTemplate.h <==
// public abstract class java.awt.GraphicsConfigTemplate

// class file dependencies
// @dep_class e171c7d57665f0cd java_awt_GraphicsConfigTemplate
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_GraphicsConfigTemplate_H_
#define _JC_java_awt_GraphicsConfigTemplate_H_

// Forward structure declarations
struct _jc_java_awt_GraphicsConfiguration$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_GraphicsConfigTemplate$sub_refs	_jc_java_awt_GraphicsConfigTemplate$sub_refs;
typedef struct _jc_java_awt_GraphicsConfigTemplate$sub_nonrefs	_jc_java_awt_GraphicsConfigTemplate$sub_nonrefs;
typedef struct _jc_java_awt_GraphicsConfigTemplate$refs	_jc_java_awt_GraphicsConfigTemplate$refs;
typedef struct _jc_java_awt_GraphicsConfigTemplate$nonrefs	_jc_java_awt_GraphicsConfigTemplate$nonrefs;
typedef struct _jc_java_awt_GraphicsConfigTemplate$object	_jc_java_awt_GraphicsConfigTemplate$object;

typedef struct _jc_java_awt_GraphicsConfigTemplate$fields_struct	_jc_java_awt_GraphicsConfigTemplate$fields_struct;
typedef const struct _jc_java_awt_GraphicsConfigTemplate$vmethods	_jc_java_awt_GraphicsConfigTemplate$vmethods;
typedef const struct _jc_java_awt_GraphicsConfigTemplate$vtable	_jc_java_awt_GraphicsConfigTemplate$vtable;
typedef const struct _jc_java_awt_GraphicsConfigTemplate$vtype	_jc_java_awt_GraphicsConfigTemplate$vtype;

// Class fields structure
struct _jc_java_awt_GraphicsConfigTemplate$fields_struct {
	jlong	serialVersionUID;
	jint	PREFERRED;
	jint	REQUIRED;
	jint	UNNECESSARY;
};
extern _jc_java_awt_GraphicsConfigTemplate$fields_struct _jc_java_awt_GraphicsConfigTemplate$class_fields;

// Constructors
extern void _jc_java_awt_GraphicsConfigTemplate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *);

// Virtual methods
extern struct _jc_java_awt_GraphicsConfiguration$object *_jc_java_awt_GraphicsConfigTemplate$method$getBestConfiguration$803551ecb7a475c0(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *, struct _jc_object_array *);
extern jboolean _jc_java_awt_GraphicsConfigTemplate$method$isGraphicsConfigSupported$fe99414413b1e974(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *, struct _jc_java_awt_GraphicsConfiguration$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_GraphicsConfigTemplate$method_info$getBestConfiguration$803551ecb7a475c0;
extern _jc_method _jc_java_awt_GraphicsConfigTemplate$method_info$isGraphicsConfigSupported$fe99414413b1e974;

// Virtual methods structure
struct _jc_java_awt_GraphicsConfigTemplate$vmethods {
	struct _jc_java_awt_GraphicsConfiguration$object	*(*getBestConfiguration$803551ecb7a475c0)(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *, struct _jc_object_array *);
	jboolean	(*isGraphicsConfigSupported$fe99414413b1e974)(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *, struct _jc_java_awt_GraphicsConfiguration$object *);
};

// Vtable
struct _jc_java_awt_GraphicsConfigTemplate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_GraphicsConfigTemplate$vmethods	java_awt_GraphicsConfigTemplate;
};

// Vtype
struct _jc_java_awt_GraphicsConfigTemplate$vtype {
	_jc_type			type;
	_jc_java_awt_GraphicsConfigTemplate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_GraphicsConfigTemplate$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_GraphicsConfigTemplate$refs {
    _jc_java_awt_GraphicsConfigTemplate$sub_refs	java_awt_GraphicsConfigTemplate;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_GraphicsConfigTemplate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_GraphicsConfigTemplate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_GraphicsConfigTemplate$sub_nonrefs	java_awt_GraphicsConfigTemplate;
};

// Object instance structure
struct _jc_java_awt_GraphicsConfigTemplate$object {
	_jc_java_awt_GraphicsConfigTemplate$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_GraphicsConfigTemplate$vtype	*vtype;
	_jc_java_awt_GraphicsConfigTemplate$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_GraphicsConfigTemplate$vtype _jc_java_awt_GraphicsConfigTemplate$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_GraphicsConfigTemplate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_GraphicsConfigTemplate$class_object;

#endif	/* _JC_java_awt_GraphicsConfigTemplate_H_ */

==> jc-1.4.6.tar.gz: java/awt/GraphicsConfigTemplate.h <==
// public abstract class java.awt.GraphicsConfigTemplate

// class file dependencies
// @dep_class e171c7d57665f0cd java_awt_GraphicsConfigTemplate
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_GraphicsConfigTemplate_H_
#define _JC_java_awt_GraphicsConfigTemplate_H_

// Forward structure declarations
struct _jc_java_awt_GraphicsConfiguration$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_GraphicsConfigTemplate$sub_refs	_jc_java_awt_GraphicsConfigTemplate$sub_refs;
typedef struct _jc_java_awt_GraphicsConfigTemplate$sub_nonrefs	_jc_java_awt_GraphicsConfigTemplate$sub_nonrefs;
typedef struct _jc_java_awt_GraphicsConfigTemplate$refs	_jc_java_awt_GraphicsConfigTemplate$refs;
typedef struct _jc_java_awt_GraphicsConfigTemplate$nonrefs	_jc_java_awt_GraphicsConfigTemplate$nonrefs;
typedef struct _jc_java_awt_GraphicsConfigTemplate$object	_jc_java_awt_GraphicsConfigTemplate$object;

typedef struct _jc_java_awt_GraphicsConfigTemplate$fields_struct	_jc_java_awt_GraphicsConfigTemplate$fields_struct;
typedef const struct _jc_java_awt_GraphicsConfigTemplate$vmethods	_jc_java_awt_GraphicsConfigTemplate$vmethods;
typedef const struct _jc_java_awt_GraphicsConfigTemplate$vtable	_jc_java_awt_GraphicsConfigTemplate$vtable;
typedef const struct _jc_java_awt_GraphicsConfigTemplate$vtype	_jc_java_awt_GraphicsConfigTemplate$vtype;

// Class fields structure
struct _jc_java_awt_GraphicsConfigTemplate$fields_struct {
	jlong	serialVersionUID;
	jint	PREFERRED;
	jint	REQUIRED;
	jint	UNNECESSARY;
};
extern _jc_java_awt_GraphicsConfigTemplate$fields_struct _jc_java_awt_GraphicsConfigTemplate$class_fields;

// Constructors
extern void _jc_java_awt_GraphicsConfigTemplate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_GraphicsConfiguration$object *_jc_java_awt_GraphicsConfigTemplate$method$getBestConfiguration$803551ecb7a475c0(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_GraphicsConfigTemplate$method$isGraphicsConfigSupported$fe99414413b1e974(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *, struct _jc_java_awt_GraphicsConfiguration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_GraphicsConfigTemplate$method_info$getBestConfiguration$803551ecb7a475c0;
extern _jc_method _jc_java_awt_GraphicsConfigTemplate$method_info$isGraphicsConfigSupported$fe99414413b1e974;

// Virtual methods structure
struct _jc_java_awt_GraphicsConfigTemplate$vmethods {
	struct _jc_java_awt_GraphicsConfiguration$object	*(*getBestConfiguration$803551ecb7a475c0)(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	jboolean	(*isGraphicsConfigSupported$fe99414413b1e974)(_jc_env *, struct _jc_java_awt_GraphicsConfigTemplate$object *, struct _jc_java_awt_GraphicsConfiguration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_GraphicsConfigTemplate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_GraphicsConfigTemplate$vmethods	java_awt_GraphicsConfigTemplate;
};

// Vtype
struct _jc_java_awt_GraphicsConfigTemplate$vtype {
	_jc_type			type;
	_jc_java_awt_GraphicsConfigTemplate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_GraphicsConfigTemplate$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_GraphicsConfigTemplate$refs {
    _jc_java_awt_GraphicsConfigTemplate$sub_refs	java_awt_GraphicsConfigTemplate;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_GraphicsConfigTemplate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_GraphicsConfigTemplate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_GraphicsConfigTemplate$sub_nonrefs	java_awt_GraphicsConfigTemplate;
};

// Object instance structure
struct _jc_java_awt_GraphicsConfigTemplate$object {
	_jc_java_awt_GraphicsConfigTemplate$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_GraphicsConfigTemplate$vtype	*vtype;
	_jc_java_awt_GraphicsConfigTemplate$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_GraphicsConfigTemplate$vtype _jc_java_awt_GraphicsConfigTemplate$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_GraphicsConfigTemplate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_GraphicsConfigTemplate$class_object;

#endif	/* _JC_java_awt_GraphicsConfigTemplate_H_ */
